@@ -253,7 +253,8 @@ class OpenApiServer:
     def register_endpoint(self, rpc_endpoint: RpcEndpoint) -> None:
         self.register(rpc_endpoint)
 
-    def register(self, rpc_endpoint: RpcEndpoint) -> None:
-        self.context.http_server.register_handler(rpc_endpoint.path, rpc_endpoint.gen_handler(), [rpc_endpoint.method])
-        self.wrapper.register(rpc_endpoint.as_endpoint())
-        self._write_spec_to_file()
+    def register(self, *rpc_endpoints: RpcEndpoint) -> None:
+        for endpoint in rpc_endpoints:
+            self.context.http_server.register_handler(endpoint.path, endpoint.gen_handler(), [endpoint.method])
+            self.wrapper.register(endpoint.as_endpoint())
+            self._write_spec_to_file()
